import SwiftUI
import TriforkSwiftLogger
import TriforkSwiftDependencyInjection

struct OnboardingView: View {

    @Inject private var logger: LoggerProtocol
    @State private var currentIndex = 0

    private let steps = OnboardingStepsFactory.steps

    var body: some View {
        VStack {
            TabView(selection: $currentIndex) {
                ForEach(steps.indices) { index in
                    OnboardingStepView(viewModel: steps[index])
                        .tag(index)
                }
            }
            .onAppear(perform: {
                UIScrollView.appearance().bounces = false
            })
            .tabViewStyle(PageTabViewStyle(indexDisplayMode: .never))
            Spacer()
            PageIndicators(numberOfPages: steps.count, currentIndex: currentIndex)
            Spacer(minLength: 20)
            VStack {
                SUIButton<PrimaryButton>(title: R.string.localizable.onboarding_login_nemid_button()) {
                    logger.default("ACTION! 🥳")
                }
                .frame(height: Metrics.Sizes.buttonHeight)
                SUIButton<SecondaryButton>(title: R.string.localizable.onboarding_login_get_started_button()) {
                    logger.default("ACTION! 🥳")
                }
                .frame(height: Metrics.Sizes.buttonHeight)
            }.padding()
        }
    }
}

struct OnboardingView_Previews: PreviewProvider {
    static var previews: some View {
        Group {
            OnboardingView()
                .previewDevice("iPhone 11 Pro")

            OnboardingView()
                .previewDevice("iPhone 8")
        }
    }
}
